@@ -88,7 +88,7 @@ class CommentFullThreadText(CommentFullTextView):
             strings.append(comment.view('fulltext', indentlevel=indentlevel-i,
                                         withauthor=i!=indentlevel).strip() + '\n')
         strings.append(u'\n%s: %s' % (self._cw._('i18n_by_author_field'),
-                                      e.dc_creator() or _('unknown author')))
+                                      e.dc_creator() or self._cw._('unknown author')))
         strings.append(u'url: %s' % itree.root().absolute_url())
         self.w(u'\n'.join(strings))
 
